@@ -5,13 +5,13 @@ mod integration {
     use core::time;
     use std::thread;
 
-    use crosstown_bus::new_rabbit_bus;
+    use crosstown_bus::Bus;
     use futures::executor::block_on;
 
     #[test]
     fn create_subscription() {
         block_on(async {
-            let bus = new_rabbit_bus("amqp://guest:guest@localhost:5672".to_string());
+            let bus = Bus::new_rabbit_bus("amqp://guest:guest@localhost:5672".to_string()).unwrap();
 
             let _ = bus.subscribe_event(String::from("user_created"), String::from("send_email"), |message| {
                 println!("User CREATED email sent now: {}", message);
@@ -28,10 +28,12 @@ mod integration {
                 (false, Ok(()))
             });
 
-            let _ = bus.publish_event(String::from("user_created"), String::from("Paolo"));
+            let res = bus.publish_event(String::from("user_created"), String::from("Paolo"));
             let _ = bus.publish_event(String::from("user_updated"), String::from("Paolo Victor"));
             let _ = bus.publish_event(String::from("user_created"), String::from("Thayna"));
 
+            assert!(res.is_ok());
+
             let _ = thread::sleep(time::Duration::from_secs(10));
         });
     }
